@@ -5,7 +5,7 @@
  #include <string.h>
  #include <time.h>
 -/*#include <cassert>*/
-+/*#include <assert.h>*/
++#include <assert.h>
  #include <math.h>
  
  /*#define STAT*/	/* Define STAT to generate a statistics log, stat.txt */
